@@ -41,10 +41,6 @@ static char *last_dir[] = { NULL, NULL, NULL, NULL };
 
 #define FILE_FORMAT_KEY "file-format"
 
-#define EOM_FILE_CHOOSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
-					     EOM_TYPE_FILE_CHOOSER,		    \
-					     EomFileChooserPrivate))
-
 struct _EomFileChooserPrivate
 {
 	MateDesktopThumbnailFactory *thumb_factory;
@@ -55,7 +51,7 @@ struct _EomFileChooserPrivate
 	GtkWidget *creator_label;
 };
 
-G_DEFINE_TYPE(EomFileChooser, eom_file_chooser, GTK_TYPE_FILE_CHOOSER_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (EomFileChooser, eom_file_chooser, GTK_TYPE_FILE_CHOOSER_DIALOG)
 
 static void
 eom_file_chooser_finalize (GObject *object)
@@ -76,14 +72,12 @@ eom_file_chooser_class_init (EomFileChooserClass *klass)
 	GObjectClass *object_class = (GObjectClass *) klass;
 
 	object_class->finalize = eom_file_chooser_finalize;
-
-	g_type_class_add_private (object_class, sizeof (EomFileChooserPrivate));
 }
 
 static void
 eom_file_chooser_init (EomFileChooser *chooser)
 {
-	chooser->priv = EOM_FILE_CHOOSER_GET_PRIVATE (chooser);
+	chooser->priv = eom_file_chooser_get_instance_private (chooser);
 }
 
 static void
@@ -451,24 +445,24 @@ eom_file_chooser_new (GtkFileChooserAction action)
 	switch (action) {
 	case GTK_FILE_CHOOSER_ACTION_OPEN:
 		gtk_dialog_add_buttons (GTK_DIALOG (chooser),
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+					"gtk-cancel", GTK_RESPONSE_CANCEL,
+					"gtk-open", GTK_RESPONSE_OK,
 					NULL);
 		title = _("Open Image");
 		break;
 
 	case GTK_FILE_CHOOSER_ACTION_SAVE:
 		gtk_dialog_add_buttons (GTK_DIALOG (chooser),
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+					"gtk-cancel", GTK_RESPONSE_CANCEL,
+					"gtk-save", GTK_RESPONSE_OK,
 					NULL);
 		title = _("Save Image");
 		break;
 
 	case GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER:
 		gtk_dialog_add_buttons (GTK_DIALOG (chooser),
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+					"gtk-cancel", GTK_RESPONSE_CANCEL,
+					"gtk-open", GTK_RESPONSE_OK,
 					NULL);
 		title = _("Open Folder");
 		break;
