@@ -24,6 +24,7 @@
 #endif
 
 #define GDK_PIXBUF_ENABLE_BACKEND
+#include <gdk/gdkx.h>
 
 #include "eom-image.h"
 #include "eom-image-private.h"
@@ -58,7 +59,7 @@
 #include <libexif/exif-loader.h>
 #endif
 
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 #include <lcms2.h>
 #ifndef EXIF_TAG_GAMMA
 #define EXIF_TAG_GAMMA 0xa500
@@ -142,9 +143,11 @@ eom_image_free_mem_private (EomImage *image)
 		}
 #endif
 
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 		if (priv->profile != NULL) {
-			cmsCloseProfile (priv->profile);
+			if (GDK_IS_X11_DISPLAY (gdk_display_get_default ())) {
+				cmsCloseProfile (priv->profile);
+			}
 			priv->profile = NULL;
 		}
 #endif
@@ -306,7 +309,7 @@ eom_image_init (EomImage *img)
 #ifdef HAVE_EXEMPI
 	img->priv->xmp = NULL;
 #endif
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 	img->priv->profile = NULL;
 #endif
 #ifdef HAVE_RSVG
@@ -616,7 +619,7 @@ eom_image_get_file_info (EomImage *img,
 	}
 }
 
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 void
 eom_image_apply_display_profile (EomImage *img, cmsHPROFILE screen)
 {
@@ -630,6 +633,9 @@ eom_image_apply_display_profile (EomImage *img, cmsHPROFILE screen)
 	priv = img->priv;
 
 	if (screen == NULL) return;
+	if (!GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+		return;
+	}
 
 	if (priv->profile == NULL) {
 		/* Check whether GdkPixbuf was able to extract a profile */
@@ -1062,7 +1068,7 @@ eom_image_real_load (EomImage *img,
 				if (set_metadata) {
 					eom_image_set_exif_data (img, md_reader);
 
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 					eom_image_set_icc_data (img, md_reader);
 #endif
 
@@ -1130,7 +1136,7 @@ eom_image_real_load (EomImage *img,
                     priv->image = rsvg_handle_get_pixbuf (priv->svg);
                 } else
 #endif
-                
+
                 {
 
 		priv->anim = gdk_pixbuf_loader_get_animation (loader);
@@ -1348,7 +1354,7 @@ eom_image_get_pixbuf (EomImage *img)
 	return image;
 }
 
-#ifdef HAVE_LCMS
+#if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 cmsHPROFILE
 eom_image_get_profile (EomImage *img)
 {
@@ -2274,7 +2280,7 @@ eom_image_iter_advance (EomImage *img)
 
 	priv = img->priv;
 
-	if ((new_frame = gdk_pixbuf_animation_iter_advance (img->priv->anim_iter, NULL)) == TRUE) {      
+	if ((new_frame = gdk_pixbuf_animation_iter_advance (img->priv->anim_iter, NULL)) == TRUE) {
 		g_mutex_lock (&priv->status_mutex);
 		g_object_unref (priv->image);
 		priv->image = gdk_pixbuf_animation_iter_get_pixbuf (priv->anim_iter);
@@ -2303,7 +2309,7 @@ eom_image_iter_advance (EomImage *img)
  * Checks whether a given image is animated.
  *
  * Returns: #TRUE if it is an animated image, #FALSE otherwise.
- * 
+ *
  **/
 gboolean
 eom_image_is_animation (EomImage *img)
@@ -2318,7 +2324,7 @@ private_timeout (gpointer data)
 	EomImage *img = EOM_IMAGE (data);
 	EomImagePrivate *priv = img->priv;
 
-	if (eom_image_is_animation (img) && 
+	if (eom_image_is_animation (img) &&
 	    !g_source_is_destroyed (g_main_current_source ()) &&
 	    priv->is_playing) {
 		while (eom_image_iter_advance (img) != TRUE) {}; /* cpu-sucking ? */
