@@ -32,8 +32,6 @@
 #define EOM_LIST_STORE_GET_PRIVATE(object) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_LIST_STORE, EomListStorePrivate))
 
-G_DEFINE_TYPE (EomListStore, eom_list_store, GTK_TYPE_LIST_STORE);
-
 struct _EomListStorePrivate {
 	GList *monitors;          /* Monitors for the directories */
 	gint initial_image;       /* The image that should be selected firstly by the view. */
@@ -42,18 +40,7 @@ struct _EomListStorePrivate {
 	GMutex mutex;            /* Mutex for saving the jobs in the model */
 };
 
-static void
-eom_list_store_finalize (GObject *object)
-{
-	EomListStore *store = EOM_LIST_STORE (object);
-
-	if (store->priv != NULL) {
-		g_free (store->priv);
-		store->priv = NULL;
-	}
-
-	G_OBJECT_CLASS (eom_list_store_parent_class)->finalize (object);
-}
+G_DEFINE_TYPE_WITH_PRIVATE (EomListStore, eom_list_store, GTK_TYPE_LIST_STORE);
 
 static void
 foreach_monitors_free (gpointer data, gpointer user_data)
@@ -93,10 +80,7 @@ eom_list_store_class_init (EomListStoreClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->finalize = eom_list_store_finalize;
 	object_class->dispose = eom_list_store_dispose;
-
-	g_type_class_add_private (object_class, sizeof (EomListStorePrivate));
 }
 
 /*
@@ -166,7 +150,7 @@ eom_list_store_init (EomListStore *self)
 	gtk_list_store_set_column_types (GTK_LIST_STORE (self),
 					 EOM_LIST_STORE_NUM_COLUMNS, types);
 
-	self->priv = EOM_LIST_STORE_GET_PRIVATE (self);
+	self->priv = eom_list_store_get_instance_private (self);
 
 	self->priv->monitors = NULL;
 	self->priv->initial_image = -1;
@@ -491,8 +475,9 @@ directory_visit (GFile *directory,
 	mime_type = g_file_info_get_content_type (children_info);
 	name = g_file_info_get_name (children_info);
 
-        if (!g_str_has_prefix (name, ".")) {
-		if (eom_image_is_supported_mime_type (mime_type)) {
+	if (!g_str_has_prefix (name, ".")) {
+		/* We support opening any image type, so let eom to add any images in the current directory to the store */
+		if (g_content_type_is_mime_type (mime_type, "image/*") || eom_image_is_supported_mime_type (mime_type)) {
 			load_uri = TRUE;
 		}
 	}
