@@ -201,21 +201,13 @@ set_default_values (GtkWidget *dlg, GFile *base_file)
 GtkWidget*
 eom_save_as_dialog_new (GtkWindow *main, GList *images, GFile *base_file)
 {
-	char *filepath;
 	GtkBuilder  *xml;
 	GtkWidget *dlg;
 	SaveAsData *data;
 	GtkWidget *label;
 
-	filepath = g_build_filename (EOM_DATA_DIR,
-				     "eom-multiple-save-as-dialog.ui",
-				     NULL);
-
-	xml = gtk_builder_new ();
+	xml = gtk_builder_new_from_resource ("/org/gnome/eog/ui/eom-multiple-save-as-dialog.ui");
 	gtk_builder_set_translation_domain (xml, GETTEXT_PACKAGE);
-	g_assert (gtk_builder_add_from_file (xml, filepath, NULL));
-
-	g_free (filepath);
 
 	dlg = GTK_WIDGET (g_object_ref (gtk_builder_get_object (xml, "eom_multiple_save_as_dialog")));
 	gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (main));
